==> sumo_1.8.0+dfsg2.orig.tar.xz: sumo-1.8.0/docs/web/docs/Other/Links.md <==
---
title: Other/Links
permalink: /Other/Links/
---

## Open Source Development

### Hosts

- [sourceforge.net](https://sourceforge.net/) Host of open-source
  projects (about 100.000).
- [freshmeat.net](http://freshmeat.net/) Portal to free applications

### How To Contribute

- [5 Ways to Contribute to Open Source Projects Without
  Coding](https://nongeeksight.blogspot.com/2006/09/5-ways-to-contribute-to-open-source.html)

## Programming Tools

### Documentation

- [Doxygen](http://www.doxygen.nl/) A class
  documentation utility.
- [XMLMind XML Editor](http://www.xmlmind.com/xmleditor/) An editor
  supporting DocBook.
- [DocBook - HowTo](https://supportweb.cs.bham.ac.uk/docs/tutorials/docsystem/build/tutorials/docbooksys/docbooksys.html)
  A description of how to use DocBook, the format used for
  SUMO-documentation.

### Software Engineering

- [SourceMonitor](http://www.campwoodsw.com/sourcemonitor.html) A
  great source code metrics tool.

### Configuration Tools

- [Autoconf](ftp://ftp.gnu.org/pub/gnu/autoconf/) Autoconf ftp-site.
- [Automake](ftp://ftp.gnu.org/pub/gnu/automake/) Automake ftp-site.

## Open Source Traffic Simulation Packages

### Road Traffic in General

- [Matsim](http://www.matsim.org/) A mesoscopic simulation package.
- [JUTS - J-Sim based Urban Traffic
  Simulator](http://home.zcu.cz/~tazman/thesis/) A road traffic
  simulation based on cellular automata written in Java. \[not
  revised\].
- [Trafix](http://trafix.sourceforge.net/) A road traffic simulation
  based on cellular automata written in C++. \[not revised\].
- [Visual Traffic
  Simulation](http://mysite.wanadoo-members.co.uk/tomfotherby/Contents/Uni/Project/index.html)
  A java application which allows to build own networks and simulate
  them. \[not revised\].
- [MITRASIM-2000](http://www.esat.kuleuven.ac.be/~smaerivo/website/phdresearch/index.php?page=mitrasim-2000)
  An (open source?) traffic simulation in Java. \[not revised\].
- [Traffic Cellular
  Automata+](http://www.esat.kuleuven.ac.be/~smaerivo/website/phdresearch/index.php?page=sm-tca)
  A java application to test cellular automata traffic models. Very
  nice, but runs on Java1.3 only.
- [BABSIM](http://www.babsim.de/) A simulation mainly concentrating on
  highways (BAB=BundesAutoBahnen, Federal Highways). Not yet given o
  the public.
- [TraffSpot](http://traffspot.db-nico.de/) A microscopic simulation
  with a nice 3D-view.

### Traffic Lights Optimisation

- [Green Light District](http://stoplicht.sourceforge.net/) A software
  for testing optimisation methods from the artificial intelligence,
  such as reinforcement or genetic algorithms on their abilities to
  optimise traffic lights within a complex environment. Seems to be
  closed in July, 2001., works pretty fine.

### Applets

- [Microsimulation of Road Traffic](http://www.traffic-simulation.de/)
  A very neat simulation applet based on the IDM-model that includes
  lane changing by Martin Treiber.

==> sumo_1.15.0+dfsg.orig.tar.xz: sumo-1_15_0/docs/web/docs/Other/Links.md <==
---
title: Links
---

## Open Source Development

### Hosts

- [sourceforge.net](https://sourceforge.net/) Host of open-source
  projects (about 100.000).

### How To Contribute

- [5 Ways to Contribute to Open Source Projects Without
  Coding](https://nongeeksight.blogspot.com/2006/09/5-ways-to-contribute-to-open-source.html)

## Programming Tools

### Documentation

- [Doxygen](http://www.doxygen.nl/) A class
  documentation utility.
- [XMLMind XML Editor](http://www.xmlmind.com/xmleditor/) An editor
  supporting DocBook.
- [MkDocs](https://www.mkdocs.org/)
  MkDocs, the tool used to build the SUMO-documentation.

### Software Engineering

- [SourceMonitor](http://www.campwoodsw.com/sourcemonitor.html) A
  great source code metrics tool.

### Configuration Tools

- [Autoconf](ftp://ftp.gnu.org/pub/gnu/autoconf/) Autoconf ftp-site.
- [Automake](ftp://ftp.gnu.org/pub/gnu/automake/) Automake ftp-site.

## Open Source Traffic Simulation Packages

### Road Traffic in General

- [Matsim](http://www.matsim.org/) A mesoscopic simulation package.
- [Trafix](http://trafix.sourceforge.net/) A road traffic simulation
  based on cellular automata written in C++. \[not revised\].
- [Visual Traffic
  Simulation](http://mysite.wanadoo-members.co.uk/tomfotherby/Contents/Uni/Project/index.html)
  A java application which allows to build own networks and simulate
  them. \[not revised\].
- [MITRASIM-2000](http://www.maerivoet.org/index.php?page=traffic-mitrasim-2000)
  An (open source?) traffic simulation in Java. \[not revised\].
- [BABSIM](https://www.inf.bi.ruhr-uni-bochum.de/index.php?option=com_content&view=article&id=17:babsim&catid=81&Itemid=116&lang=de) A simulation mainly concentrating on
  highways (BAB=BundesAutoBahnen, Federal Highways). Not yet given o
  the public.
- [TraffSpot](http://traffspot.db-nico.de/) A microscopic simulation
  with a nice 3D-view.

### Traffic Lights Optimisation

- [Green Light District](https://sourceforge.net/projects/stoplicht/) A software
  for testing optimisation methods from the artificial intelligence,
  such as reinforcement or genetic algorithms on their abilities to
  optimise traffic lights within a complex environment. Seems to be
  closed in July, 2001., works pretty fine.

### Applets

- [Microsimulation of Road Traffic](http://www.traffic-simulation.de/)
  A very neat simulation applet based on the IDM-model that includes
  lane changing by Martin Treiber.
